@@ -41,22 +41,21 @@ void KIOServices::onAccountCreated(const Accounts::AccountId accId, const Accoun
 {
     for (const Accounts::Service &service : serviceList) {
         if (service.serviceType() != QLatin1String("dav-storage")) {
-            qCDebug(KACCOUNTS_DAV_LOG) << "Ignoring: " << service.serviceType();
+            qCDebug(KACCOUNTS_DAV_LOG) << "Ignoring:" << service.serviceType();
             continue;
         }
         if (isEnabled(accId, service.name())) {
-            qCDebug(KACCOUNTS_DAV_LOG) << "Already configured: " << service.name();
+            qCDebug(KACCOUNTS_DAV_LOG) << "Already configured:" << service.name();
             continue;
         }
 
-        qCDebug(KACCOUNTS_DAV_LOG) << "Creating: " << service.name() << "Of type: " << service.serviceType();
+        qCDebug(KACCOUNTS_DAV_LOG) << "Creating:" << service.name() << "Of type:" << service.serviceType();
         enableService(accId, service);
     }
 }
 
 void KIOServices::onAccountRemoved(const Accounts::AccountId accId)
 {
-    qCDebug(KACCOUNTS_DAV_LOG);
     const QString accountId = QString::number(accId) + QStringLiteral("_");
 
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/remoteview/");
@@ -69,7 +68,7 @@ void KIOServices::onAccountRemoved(const Accounts::AccountId accId)
         }
 
         QString serviceName = i.fileName();
-        qCDebug(KACCOUNTS_DAV_LOG) << "Removing: " << serviceName;
+        qCDebug(KACCOUNTS_DAV_LOG) << "Removing:" << serviceName;
         serviceName = serviceName.mid(accountId.count(), serviceName.indexOf(QLatin1String(".desktop")) - accountId.count());
         qCDebug(KACCOUNTS_DAV_LOG) << "Removing N: " << serviceName;
         disableService(accId, serviceName);
@@ -79,11 +78,11 @@ void KIOServices::onAccountRemoved(const Accounts::AccountId accId)
 void KIOServices::onServiceEnabled(const Accounts::AccountId accId, const Accounts::Service &service)
 {
     if (service.serviceType() != QLatin1String("dav-storage")) {
-        qCDebug(KACCOUNTS_DAV_LOG) << "Ignoring: " << service.serviceType();
+        qCDebug(KACCOUNTS_DAV_LOG) << "Ignoring:" << service.serviceType();
         return;
     }
     if (isEnabled(accId, service.name())) {
-        qCDebug(KACCOUNTS_DAV_LOG) << "Already configured: " << service.name();
+        qCDebug(KACCOUNTS_DAV_LOG) << "Already configured:" << service.name();
         return;
     }
 
@@ -93,11 +92,11 @@ void KIOServices::onServiceEnabled(const Accounts::AccountId accId, const Accoun
 void KIOServices::onServiceDisabled(const Accounts::AccountId accId, const Accounts::Service &service)
 {
     if (service.serviceType() != QLatin1String("dav-storage")) {
-        qCDebug(KACCOUNTS_DAV_LOG) << "Ignoring: " << service.serviceType();
+        qCDebug(KACCOUNTS_DAV_LOG) << "Ignoring:" << service.serviceType();
         return;
     }
     if (!isEnabled(accId, service.name())) {
-        qCDebug(KACCOUNTS_DAV_LOG) << "Already not configured: " << service.name();
+        qCDebug(KACCOUNTS_DAV_LOG) << "Already not configured:" << service.name();
         return;
     }
 
@@ -178,10 +177,7 @@ QCoro::Task<void> KIOServices::createNetAttach(const Accounts::AccountId account
     }
     const QString desktopFilePath = folderPath + QString::number(accountId) + QLatin1Char('_') + service.name() + QStringLiteral(".desktop");
 
-    qCDebug(KACCOUNTS_DAV_LOG) << "Creating knetAttach place";
-    qCDebug(KACCOUNTS_DAV_LOG) << desktopFilePath;
-    qCDebug(KACCOUNTS_DAV_LOG) << url.host();
-    qCDebug(KACCOUNTS_DAV_LOG) << url.toString();
+    qCDebug(KACCOUNTS_DAV_LOG) << "Creating knetAttach place" << desktopFilePath << url.host() << url.toString();
 
     KConfig _desktopFile(desktopFilePath, KConfig::SimpleConfig);
     KConfigGroup desktopFile(&_desktopFile, QStringLiteral("Desktop Entry"));
